this.name					= "wildShips_populator.js";
this.author					= "Thargoid";
this.copyright				= "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description			= "Script to add Kiota stations to certain systems";
this.version				= "1.09";
"use strict";

//1.09 updated to use the core populator -spara-

this.systemWillPopulate = function (){
	this.addedCount = 0;
	//calculate distances
	var planetToSun = system.sun.position.distanceTo(system.mainPlanet.position);
	var wpToSun = system.sun.position.magnitude();
	
	//habitats
	if(system.scrambledPseudoRandomNumber(127) > 0.25) {
		// add habitat stations between the planet and sun, based on population size
		this.addedCount += 0.1;
		if (system.population < 30)
			var hab_station = "wildShips_kiota2Ring";
		else {
			if (system.population > 45) {
				if (system.scrambledPseudoRandomNumber(319) > 0.5)
					var hab_station = "wildShips_kiota8Ring";
				else
					var hab_station = "wildShips_kiota8RingV";
			}
			else {
				if(system.scrambledPseudoRandomNumber(319) > 0.5)
					var hab_station = "wildShips_kiota4Ring";
				else
					var hab_station = "wildShips_kiota4RingV";
			}
		}
		var distanceFromPlanetSurface = 0.1 * (planetToSun  - system.sun.radius - system.mainPlanet.radius);
		//randomize the position a bit
		var x_coord = system.scrambledPseudoRandomNumber(598) * 25E3;
		var y_coord = system.scrambledPseudoRandomNumber(482) * 25E3;
		var z_coord = system.mainPlanet.radius + distanceFromPlanetSurface;
		var exactPosition = Vector3D(x_coord, y_coord, z_coord).fromCoordinateSystem("psm");
		system.setPopulator("wild_ships_habitat", {
			callback: function(pos) {			
				system.addShips(hab_station, 1, pos, 0);					
			}.bind(this),
			location: "COORDINATES",
			coordinates: exactPosition,
			deterministic: true
		})
	}

	//comms stations
	if(system.scrambledPseudoRandomNumber(891) > (0.5 + this.addedCount)) {
		// add comms stations
		this.addedCount += 0.1;
		if(system.population > 40)
			var comms_station = "wildShips_kiota4Comms";
		else
			var comms_station = "wildShips_kiota2Comms";
		var distanceFromWp = 0.3 * (wpToSun  - system.sun.radius);
		//randomize the position a bit
		var x_coord = system.scrambledPseudoRandomNumber(599) * 25E3;
		var y_coord = system.scrambledPseudoRandomNumber(483) * 25E3;
		var z_coord = distanceFromWp;
		var exactPosition = Vector3D(x_coord, y_coord, z_coord).fromCoordinateSystem("wsm");
		system.setPopulator("wild_ships_comms", {
			callback: function(pos) {			
				system.addShips(comms_station, 1, pos, 0);					
			}.bind(this),
			location: "COORDINATES",
			coordinates: exactPosition,
			deterministic: true
		})
	}
		
	//solar stations
	if(system.scrambledPseudoRandomNumber(189) > (0.5 + this.addedCount)) {
		// add solar stations
		this.addedCount += 0.1;
		if(system.population > 40)
			var solar_station = "wildShips_kiota4Solar";
		else
			var solar_station = "wildShips_kiota2Solar";
		var distanceFromPlanetSurface = 0.9 * (planetToSun  - system.sun.radius - system.mainPlanet.radius);
		//randomize the position a bit
		var x_coord = system.scrambledPseudoRandomNumber(600) * 25E3;
		var y_coord = system.scrambledPseudoRandomNumber(484) * 25E3;
		var z_coord = system.mainPlanet.radius + distanceFromPlanetSurface;
		var exactPosition = Vector3D(x_coord, y_coord, z_coord).fromCoordinateSystem("psm");
		system.setPopulator("wild_ships_solar", {
			callback: function(pos) {			
				system.addShips(solar_station, 1, pos, 0);					
			}.bind(this),
			location: "COORDINATES",
			coordinates: exactPosition,
			deterministic: true
		})		
	}
	
	//research stations
	if(system.techLevel > 6 && system.scrambledPseudoRandomNumber(713) > (0.5 + this.addedCount)) {
		// add research stations to higher tech systems
		this.addedCount += 0.1;
		if(system.techLevel > 11)
			var research_station = "wildShips_kiota4Spur";
		else
			var research_station = "wildShips_kiota2Spur";

		var distanceFromWp = 0.6 * (wpToSun  - system.sun.radius);
		//randomize the position a bit
		var x_coord = system.scrambledPseudoRandomNumber(601) * 25E3;
		var y_coord = system.scrambledPseudoRandomNumber(485) * 25E3;
		var z_coord = distanceFromWp;
		var exactPosition = Vector3D(x_coord, y_coord, z_coord).fromCoordinateSystem("wsm");
		system.setPopulator("wild_ships_research", {
			callback: function(pos) {			
				system.addShips(research_station, 1, pos, 0);					
			}.bind(this),
			location: "COORDINATES",
			coordinates: exactPosition,
			deterministic: true
		})
	}
	
	//manufacturing stations
	if (system.scrambledPseudoRandomNumber(301) > (0.5 + this.addedCount)) {
		// add manufacturing stations to industrial systems
		if (system.economy < 3) {
			if(system.productivity > (30000 - (system.economy * 2500)))
				var man_station = "wildShips_kiota4Sphere";
			else
				var man_station = "wildShips_kiota2Sphere";
		}
		else if (system.economy > 4) {
			if(system.productivity > (30000 - ((system.economy - 5) * 2500)))
				var man_station = "wildShips_kiota4Sphere";
			else
				var man_station = "wildShips_kiota2Sphere";
		}
		else return;
		
		this.addedCount += 0.1;
		var distanceFromPlanetSurface = 0.5 * (planetToSun  - system.sun.radius - system.mainPlanet.radius);
		//randomize the position a bit
		var x_coord = system.scrambledPseudoRandomNumber(602) * 25E3;
		var y_coord = system.scrambledPseudoRandomNumber(486) * 25E3;
		var z_coord = system.mainPlanet.radius + distanceFromPlanetSurface;
		var exactPosition = Vector3D(x_coord, y_coord, z_coord).fromCoordinateSystem("psm");
		system.setPopulator("wild_ships_manufacturing", {
			callback: function(pos) {			
				system.addShips(man_station, 1, pos, 0);					
			}.bind(this),
			location: "COORDINATES",
			coordinates: exactPosition,
			deterministic: true
		})
	}
}
